@@ -362,3 +362,17 @@ def write_text_file(
     t = open(file_path, "w")
     t.write(content)
     t.close()
+
+
+def slice_list_to_chunks(lst, n):
+    """
+    Slice a list into chunks of size n.
+    Args:
+        list
+        int
+    Returns:
+        [list]
+    """
+    chunks = [lst[x:x+n] for x in range(0, len(lst), n)]
+
+    return chunks
